API docs for “spamfighter.rules.test.test_log.MessageLogPutTestCase”

# Class s.r.t.t.MessageLogPutTestCase(unittest.TestCase):

Part of spamfighter.rules.test.test_log View Source View In Hierarchy

Тест на `spamfighter.rules.log.messageLogPut`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testNoLog | Undocumented
Method | testNotALog | Undocumented
Method | testPut1 | Undocumented
Method | testPut2 | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testNoLog(self): (source)
Undocumented
def testNotALog(self): (source)
Undocumented
def testPut1(self): (source)
Undocumented
def testPut2(self): (source)
Undocumented